
# AWS SSM Session Manager Plugin (session-manager-plugin)

Install AWS SSM Session Manager plugin.

## Example Usage

```json
"features": {
    "ghcr.io/lasuillard-s/aws-annoying/session-manager-plugin:0": {}
}
```





---

_Note: This file was auto-generated from the [devcontainer-feature.json](https://github.com/lasuillard-s/aws-annoying/blob/main/devcontainer-features/src/session-manager-plugin/devcontainer-feature.json).  Add additional notes to a `NOTES.md`._
